@@ -72,7 +72,7 @@ def _bulk_change(success_lock: Lock,
         write_results(success_file_name, successes, success_lock)
     if failures:
         failure_file_name = f'{results_file_name}_failures'
-        write_results(failure_file_name, failures, failures)
+        write_results(failure_file_name, failures, failure_lock)
 
 
 def _bulk_delete(success_lock: Lock,
@@ -93,7 +93,7 @@ def _bulk_delete(success_lock: Lock,
         write_results(success_file_name, successes, success_lock)
     if failures:
         failure_file_name = f'failures_{results_file_name}'
-        write_results(failure_file_name, failures, failures)
+        write_results(failure_file_name, failures, failure_lock)
 
 
 def _read_and_chunk(file_name: str) -> List[List[dict]]:
